@@ -1,7 +1,7 @@
 from websocket import create_connection
 from json import dumps , loads
 from random import choice
-from ..encryption import Encryption
+from rubpy.encryption import Encryption
 
 ''' This library was created
 with the efforts of Shython,
